bucket/delete_bucket
Types
The parameters for the API request
pub type RequestBuilder {
RequestBuilder(
name: String,
expected_bucket_owner: option.Option(String),
)
}
Constructors
-
RequestBuilder( name: String, expected_bucket_owner: option.Option(String), )
Values
pub fn build(
builder: RequestBuilder,
creds: bucket.Credentials,
) -> request.Request(BitArray)
pub fn expected_bucket_owner(
builder: RequestBuilder,
expected_bucket_owner: String,
) -> RequestBuilder
The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code 403 Forbidden (access denied).
pub fn request(name name: String) -> RequestBuilder
pub fn response(
response: response.Response(BitArray),
) -> Result(Nil, bucket.BucketError)